@@ -96,7 +96,7 @@ def logger(body='',
            bad=False,
            timestamp=True):
     if timestamp:
-        tstamp = datetime.now().strftime('%Y-%m-%d %H:%M:%S.%f')[:-3]
+        tstamp = datetime.now().strftime('%H:%M:%S.%f')[:-3]
         click.secho(tstamp + ' ', fg=LOGGER_TIMESTAMP, nl=False)
     if head:
         click.secho(head, fg=LOGGER_COLOR, nl=False)
