@@ -1,3 +1,5 @@
+# File modified under the Apache Licence 2.0 spec. Modified by Aero Technologies.
+# Modifications made: Updated copywriting for stdout - along with logging improvements
 """
 Local backend
 
@@ -58,7 +60,8 @@ class NativeRuntime(object):
                  clone_steps=None,
                  max_workers=MAX_WORKERS,
                  max_num_splits=MAX_NUM_SPLITS,
-                 max_log_size=MAX_LOG_SIZE):
+                 max_log_size=MAX_LOG_SIZE,
+                 verbose_logging=False):
 
         if run_id is None:
             self._run_id = metadata.new_run_id()
@@ -80,6 +83,7 @@ class NativeRuntime(object):
         self._entrypoint = entrypoint
         self.event_logger = event_logger
         self._monitor = monitor
+        self._verbose_logging = verbose_logging
 
         self._clone_run_id = clone_run_id
         self._clone_steps = {} if clone_steps is None else clone_steps
@@ -456,7 +460,8 @@ class Task(object):
                  join_type=None,
                  logger=None,
                  task_id=None,
-                 decos=[]):
+                 decos=[],
+                 verbose_logging=False):
         if task_id is None:
             task_id = str(metadata.new_task_id(run_id, step))
         else:
@@ -479,6 +484,7 @@ class Task(object):
         self.metadata = metadata
         self.event_logger = event_logger
         self.monitor = monitor
+        self.verbose_logging = verbose_logging
 
         self._logger = logger
         self._path = '%s/%s/%s' % (self.run_id, self.step, self.task_id)
@@ -533,10 +539,16 @@ class Task(object):
 
 
     def log(self, msg, system_msg=False, pid=None):
-        if pid:
-            prefix = '[%s (pid %s)] ' % (self._path, pid)
+        
+        if self.verbose_logging:
+            path = self._path
         else:
-            prefix = '[%s] ' % self._path
+            path = "%s/%s" % (self.step, self.task_id)
+
+        if pid and self.verbose_logging:
+            prefix = '[%s (pid %s)] ' % (path, pid)
+        else:
+            prefix = '%s ' % path 
 
         self._logger(msg, head=prefix, system_msg=system_msg)
         sys.stdout.flush()
